@@ -729,6 +729,18 @@ static char *(features[]) =
 
 static int included_patches[] =
 {   /* Add new patch number below this line */
+/**/
+    1896,
+/**/
+    1895,
+/**/
+    1894,
+/**/
+    1893,
+/**/
+    1892,
+/**/
+    1891,
 /**/
     1890,
 /**/
@@ -5025,7 +5037,7 @@ intro_message(
 	N_("Vim is open source and freely distributable"),
 	"",
 	N_("Help poor children in Uganda!"),
-	N_("type  :help iccf<Enter>       for information "),
+	N_("type  :help Kuwasha<Enter>    for information "),
 	"",
 	N_("type  :q<Enter>               to exit         "),
 	N_("type  :help<Enter>  or  <F1>  for on-line help"),
@@ -5101,7 +5113,7 @@ intro_message(
 		    p = sponsor < 0
 			? N_("Sponsor Vim development!")
 			: N_("Become a registered Vim user!");
-		else if (strstr(p, "iccf") != NULL)
+		else if (strstr(p, "Kuwasha") != NULL)
 		    p = sponsor < 0
 			? N_("type  :help sponsor<Enter>    for information ")
 			: N_("type  :help register<Enter>   for information ");
